import router from "./router";
import store from "./store";
import { Message } from "element-ui";
import NProgress from "nprogress"; // 进度条
import "nprogress/nprogress.css"; // 进度条样式
import { getToken } from "@/utils/auth"; // 通过cookie获取token
import getPageTitle from "@/utils/get-page-title";

NProgress.configure({ showSpinner: false }); // NProgress Configuration

const whiteList = ["/login"]; // 不用权限的页面

router.beforeEach(async (to, from, next) => {
  // start progress bar
  NProgress.start();

  // 设置页面标题
  document.title = getPageTitle(to.meta.title);

  // 确定用户是否已登录
  // const hasToken = getToken();
  let hasToken = window.sessionStorage.getItem("TOKEN");

  if (hasToken) {
    // 有token则为登入状态
    if (to.path === "/login") {
      // 如果登录则重定向到首页
      next("/portal/administration");
      NProgress.done();
    } else {
      // 确定用户是否已通过getInfo获得其权限角色
      const hasAuthority = store.getters.authorityList;

      if (hasAuthority) {
        next();
      } else {
        try {
          // 角色必须是对象数组！例如：['admin']或，['developer'，'editor']
          await store.dispatch("user/getInfo");

          // 基于角色生成可访路由
          const roles = store.getters.roles;
          const accessRoutes = await store.dispatch(
            "permission/generateRoutes",
            roles
          );
          // 动态添加路由
          router.addRoutes(accessRoutes);
          // hack method to ensure that addRoutes is complete
          // 设置replace:true，这样导航就不会留下历史记录
          next({ ...to, replace: true });
        } catch (error) {
          // remove token and go to login page to re-login
          await store.dispatch("user/resetToken");
          Message.error({
            message: error || "出现错误"
          });
          next(`/login?redirect=${to.path}`);
          NProgress.done();
        }
      }
    }
  } else {
    // 没有token

    if (whiteList.indexOf(to.path) !== -1) {
      // 如果访问的是不要权限的路由路径 则放行
      next();
    } else {
      // 其他没有访问权限的页面将重定向到登录页面。
      next(`/login?redirect=${to.path}`);
      NProgress.done();
    }
  }
});

router.afterEach(() => {
  // finish progress bar
  NProgress.done();
});
