import { login, logout, getInfo } from "@/api/user";
import { getToken, setToken, removeToken } from "@/utils/auth";
import router, { resetRouter } from "@/router";
import { Message } from "element-ui";

const state = {
  token: getToken(),
  roles: null,
  userInfo: null,
  authorityList: null
};

const mutations = {
  SET_TOKEN: (state, token) => {
    state.token = token;
  },
  SET_AUTHORITY_LIST: (state, authorityList) => {
    state.authorityList = authorityList;
  },
  SET_ROLES: (state, roles) => {
    state.roles = roles;
  },
  SET_USER_INFO(state, data) {
    state.userInfo = data;
  }
};

const actions = {
  // user login
  login({ commit }, userInfo) {
    const { username, password } = userInfo;
    return new Promise((resolve, reject) => {
      login({ username: username.trim(), password: password })
        .then(response => {
          if (!response.success) {
            Message.error({
              message: response.errorMsg
            });
          } else {
            const { data } = response;
            commit("SET_TOKEN", data.token);
            // setToken();
            commit("SET_USER_INFO", data.userInfo);
            sessionStorage.setItem("TOKEN", data.token);
          }
          resolve();
        })
        .catch(error => {
          reject(error);
        });
    });
  },

  // 获取用户信息
  getInfo({ commit, state }) {
    return new Promise((resolve, reject) => {
      getInfo()
        .then(async response => {
          // console.log("response", response);
          const { success, data } = response;
          if (!success) {
            Message.error({
              message: "获取用户信息失败！"
            });
          } else {
            commit("SET_AUTHORITY_LIST", data.userInfo);

            // 用户角色
            commit("SET_ROLES", [data.role]);
            // commit("SET_ROLES", ["SUPERADMIN"]);
          }

          // 用户名
          resolve(response);
        })
        .catch(error => {
          reject(error);
        });
    });
  },

  // user logout
  logout({ commit }) {
    return new Promise((resolve, reject) => {
      logout(state.token)
        .then(() => {
          commit("SET_AUTHORITY_LIST", null);
          commit("SET_ROLES", null);
          commit("SET_USER_INFO", null);
          commit("SET_TOKEN", null);
          sessionStorage.removeItem("TOKEN");

          // commit("SET_ROLES", null);
          // commit("SET_AUTHORITY_LIST", null);
          // removeToken();
          resetRouter();

          resolve();
        })
        .catch(error => {
          reject(error);
        });
    });
  },

  // remove token
  resetToken({ commit }) {
    return new Promise(resolve => {
      // commit("SET_ROLES", null);
      // commit("SET_AUTHORITY_LIST", null);
      // removeToken();
      // resetRouter();

      commit("SET_AUTHORITY_LIST", null);
      commit("SET_ROLES", null);
      commit("SET_USER_INFO", null);
      commit("SET_TOKEN", null);
      sessionStorage.removeItem("TOKEN");
      resetRouter();

      resolve();
    });
  },

  // 动态修改权限
  async changeRoles({ commit, dispatch }, role) {
    const token = role + "-token";

    commit("SET_TOKEN", token);
    setToken(token);

    const { roles } = await dispatch("getInfo");

    resetRouter();

    // generate accessible routes map based on roles
    const accessRoutes = await dispatch("permission/generateRoutes", roles, {
      root: true
    });
    // dynamically add accessible routes
    router.addRoutes(accessRoutes);

    // reset visited views and cached views
    dispatch("tagsView/delAllViews", null, { root: true });
  }
};

export default {
  namespaced: true,
  state,
  mutations,
  actions
};
