import axios from "axios";
import { MessageBox, Message } from "element-ui";
import store from "@/store";
import Vue from "vue";
// import { getToken } from '@/utils/auth'

// create an axios instance
const service = axios.create({
  baseURL: process.env.VUE_APP_BASE_API, // url = base url + request url
  // withCredentials: true,
  timeout: 50000 // request timeout
});

// request interceptor
service.interceptors.request.use(
  config => {
    if (sessionStorage.getItem("TOKEN")) {
      config.headers["Authorization"] = sessionStorage.getItem("TOKEN");
    }
    return config;
  },
  error => {
    // do something with request error
    //console.log(error) // for debug
    return Promise.reject(error);
  }
);

// response interceptor
service.interceptors.response.use(
  response => {
    const res = response.data;

    // if the custom code is not 20000, it is judged as an error.

    // 50008: Illegal token; 50012: Other clients logged in; 50014: Token expired;
    console.log(res.errorCode);
    if (res.errorCode && res.errorCode === 3002) {
      // to re-login
      MessageBox.confirm("登录失效，请重新登录!", "提示", {
        confirmButtonText: "确定",
        type: "warning"
      })
        .then(() => {
          store.dispatch("user/resetToken").then(() => {
            location.reload();
          });
          // Vue.router.push("/login");
        })
        .catch(() => {});
      return Promise.reject(new Error(res.errorMsg || "遇到错误"));
    } else {
      return res;
    }
  },
  error => {
    //console.log('err' + error) // for debug
    Message({
      message: error.message,
      type: "error",
      duration: 5 * 1000
    });
    return Promise.reject(error);
  }
);

export default service;
